Struct UsbSerialJtag

pub struct UsbSerialJtag<'d, Dm: DriverMode> { /* private fields */ }
Available on crate feature unstable only.
USB Serial/JTAG (Full-duplex)

Implementations

Source

impl<'d> UsbSerialJtag<'d, Blocking>

pub fn new(usb_device: impl Peripheral<P = USB_DEVICE> + 'd) -> Self

Create a new USB serial/JTAG instance with defaults

pub fn into_async(self) -> UsbSerialJtag<'d, Async>

Reconfigure the USB Serial JTAG peripheral to operate in asynchronous mode.

Source

impl<'d, Dm> UsbSerialJtag<'d, Dm>
where Dm: DriverMode,

pub fn split(self) -> (UsbSerialJtagRx<'d, Dm>, UsbSerialJtagTx<'d, Dm>)

Split the USB Serial JTAG peripheral into a transmitter and receiver, which is particularly useful when having two tasks correlating to transmitting and receiving.

pub fn write(&mut self, data: &[u8]) -> Result<(), Infallible>

Write data to the serial output in chunks of up to 64 bytes

pub fn write_byte_nb(&mut self, word: u8) -> Result<(), Infallible>

Write data to the serial output in a non-blocking manner Requires manual flushing (automatically flushed every 64 bytes)

pub fn flush_tx(&mut self) -> Result<(), Infallible>

Flush the output FIFO and block until it has been sent

pub fn flush_tx_nb(&mut self) -> Result<(), Infallible>

Flush the output FIFO but don’t block if it isn’t ready immediately

pub fn read_byte(&mut self) -> Result<u8, Infallible>

Read a single byte but don’t block if it isn’t ready immediately

pub fn listen_rx_packet_recv_interrupt(&mut self)

Listen for RX-PACKET-RECV interrupts

pub fn unlisten_rx_packet_recv_interrupt(&mut self)

Stop listening for RX-PACKET-RECV interrupts

pub fn rx_packet_recv_interrupt_set(&mut self) -> bool

Checks if RX-PACKET-RECV interrupt is set

pub fn reset_rx_packet_recv_interrupt(&mut self)

Reset RX-PACKET-RECV interrupt

pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)

Registers an interrupt handler for the USB Serial JTAG peripheral.

Note that this will replace any previously registered interrupt handlers.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl<'d> UsbSerialJtag<'d, Async>

pub fn into_blocking(self) -> UsbSerialJtag<'d, Blocking>

Reconfigure the USB Serial JTAG peripheral to operate in blocking mode.