Struct UsbSerialJtagTx

pub struct UsbSerialJtagTx<'d, Dm: DriverMode> { /* private fields */ }
Available on crate feature unstable only.
USB Serial/JTAG (Transmit)

Implementations

Source

impl<'d, Dm> UsbSerialJtagTx<'d, Dm>
where Dm: DriverMode,

pub fn write(&mut self, data: &[u8]) -> Result<(), Infallible>

Write data to the serial output in chunks of up to 64 bytes

pub fn write_byte_nb(&mut self, word: u8) -> Result<(), Infallible>

Write data to the serial output in a non-blocking manner Requires manual flushing (automatically flushed every 64 bytes)

pub fn flush_tx(&mut self) -> Result<(), Infallible>

Flush the output FIFO and block until it has been sent

pub fn flush_tx_nb(&mut self) -> Result<(), Infallible>

Flush the output FIFO but don’t block if it isn’t ready immediately