pub struct UsbSerialJtagTx<'d, Dm: DriverMode> { /* private fields */ }unstable only.Expand description
USB Serial/JTAG (Transmit)
Implementations
Sourceimpl<'d, Dm> UsbSerialJtagTx<'d, Dm>where
Dm: DriverMode,
impl<'d, Dm> UsbSerialJtagTx<'d, Dm>where
Dm: DriverMode,
Sourcepub fn write(&mut self, data: &[u8]) -> Result<(), Infallible>
pub fn write(&mut self, data: &[u8]) -> Result<(), Infallible>
Write data to the serial output in chunks of up to 64 bytes
Sourcepub fn write_byte_nb(&mut self, word: u8) -> Result<(), Infallible>
pub fn write_byte_nb(&mut self, word: u8) -> Result<(), Infallible>
Write data to the serial output in a non-blocking manner Requires manual flushing (automatically flushed every 64 bytes)
Sourcepub fn flush_tx(&mut self) -> Result<(), Infallible>
pub fn flush_tx(&mut self) -> Result<(), Infallible>
Flush the output FIFO and block until it has been sent
Sourcepub fn flush_tx_nb(&mut self) -> Result<(), Infallible>
pub fn flush_tx_nb(&mut self) -> Result<(), Infallible>
Flush the output FIFO but don’t block if it isn’t ready immediately